@@ -1,6 +1,6 @@
 package App::jpath;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 1;
 # ABSTRACT: Command-line tool for JSON::Path
@@ -17,7 +17,7 @@ App::jpath - Command-line tool for JSON::Path
 
 =head1 VERSION
 
-version 0.03
+This document describes version 0.04 of App::jpath (from Perl distribution App-jpath), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-jpath>
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-jpath>.
+Source repository is at L<https://github.com/perlancar/perl-App-jpath>.
 
 =head1 BUGS
 
@@ -41,11 +41,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
